@@ -15,6 +15,7 @@ class GlofasForecast(Dataset):
     licence = "-"
     documentation = "-"
     citation = "-"
+    request = "-"
 
 
     terms_of_use = (
@@ -28,14 +29,14 @@ class GlofasForecast(Dataset):
     temporal_range = [2019,2021]
 
     def __init__(self, system_version, product_type, model, variable, period, leadtime):
-        
-        self.parser = Parser(temporal_range)
+
+        self.parser = Parser(self.temporal_range)
 
         years, months, days = self.parser.period(period)
 
         leadtime_hour = self.parser.leadtime(leadtime)
 
-
+ 
         self.request = {
             "system_version": system_version,
             "hydrological_model": model,
@@ -58,4 +59,21 @@ class GlofasForecast(Dataset):
         #         cml.load_source("cds", "cems-glofas-forecast", **request)
         #     )
 
-        # self.source = cml.load_source("multi", sources)
\ No newline at end of file
+        # self.source = cml.load_source("multi", sources)
+
+
+    def _repr_html_(self):
+        if self.request == "-":
+            super()._repr_html(self)
+        else:
+            style = """
+                <style>table.climetlab td {
+                vertical-align: top;
+                text-align: left !important;}
+            </style>"""      
+            
+            li = ""
+            for key in self.request:
+                li += f"<li> <b>{key}: </b> {self.request[key]} </li>".format()
+                
+            return style + f"""<table class="climetlab"><tr><td><b>Request</b></td><td><ul>{li}</ul></td></tr></table>"""
\ No newline at end of file
