@@ -6,6 +6,15 @@ M = ["%02d"%d for  d in range(1,13)]
 Y = [str(d) for d in range(2000,2019)]
 D = ["%02d"%d for  d in range(1,32)]
 
+
+
+class StringNotValidError(Exception):
+
+    def __init__(self, expression, message):
+        self.expression = expression
+        self.message = message
+
+
 def ensure_list(l):
     if isinstance(l,list):
         return l
@@ -27,8 +36,14 @@ def parser_time_index(start=[2019, 1, 1], end=[2019, 12, 31]):
 
 class Parser:
 
-    def __init__(self):
-        pass
+    def __init__(self,range_years=None):
+        
+        #TODO quite hacky
+        if range_years:
+            setattr(Parser,"Y",[str(d) for d in range(range_years[0],range_years[1]+1)])
+        else:
+            setattr(Parser,"Y",None)
+        
 
     @staticmethod
     def leadtime(string):
@@ -42,20 +57,19 @@ class Parser:
 
         return ret
 
-    @staticmethod
-    def period(string):
+    @classmethod
+    def period(cls,string):
 
         PATTERN = {"[0-9]{8}":{}, # most frequent
-                "\*[0-9]{2}[0-9]{2}":[Y,string[1:3],string[3:]],
+                "\*[0-9]{2}[0-9]{2}":[cls.Y,string[1:3],string[3:]],
                 "[0-9]{4}\*[0-9]{2}":[string[:4],M,string[5:]],
-                "[0-9]{4}[0-9]{2}\*":{"D":D},
-                "[0-9]{4}\*\*":{"M":M,"D":D},
-                "\*[0-9]{2}\*":{"Y":Y,"D":D},
-                "\*\*[0-9]{2}":{"Y":Y,"M":M},
-                "\*\*\*":{"Y":Y,"M":M,"D":D}}
-
-        s = string.split("/")
+                "[0-9]{4}[0-9]{2}\*":[string[:4],string[1:3],D],
+                "[0-9]{4}\*\*":[string[:4],M,D],
+                "\*[0-9]{2}\*":[cls.Y,string[1:3],D],
+                "\*\*[0-9]{2}":[cls.Y,M,string[3:]],
+                "\*\*\*":[cls.Y,M,D]}
 
+        _validate(string)
 
         if "*" in string:
             years = set()
@@ -70,11 +84,14 @@ class Parser:
 
             return sorted(ensure_list(years)), sorted(ensure_list(months)), sorted(ensure_list(days))
 
-        else:
-            years = set()
-            months = set()
-            days = set()
-            for chunk in s:
+        s = string.split("/")
+
+        years = set()
+        months = set()
+        days = set()
+        for chunk in s:
+
+            if "-" in chunk: # check "-"
                 start, end = chunk.split("-")
                 start = datetime.strptime(start, "%Y%m%d")
                 end = datetime.strptime(end, "%Y%m%d")
@@ -84,10 +101,21 @@ class Parser:
                 years.update([i.strftime("%Y") for i in period])
                 months.update([i.strftime("%m") for i in period])
                 days.update([i.strftime("%d") for i in period])
-
-            return sorted(list(years)), sorted(list(months)), sorted(list(days))
+            else:
+                years.update([chunk[:4]])
+                months.update([chunk[4:6]])
+                days.update([chunk[6:]])                 
 
 
+        return sorted(list(years)), sorted(list(months)), sorted(list(days))
+
+
+
+def _validate(string):
+    if ("*" in string and "-" in string) or ("*" in string and "/" in string):
+        raise StringNotValidError(string," '*' and '-' or '*' and '/' are not allowed in the same string")
+    else:
+        pass
 
 def months_num2str(months: T.List[str]):
     mapping = {"01":"january","02":"february","03":"march","04":"april","05":"may",
